"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeaturesController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const enums_1 = require("../enums");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/features';
let FeaturesController = class FeaturesController {
    constructor(featuresRepository) {
        this.featuresRepository = featuresRepository;
    }
    async create(features) {
        return this.featuresRepository.create(features);
    }
    async count(where) {
        return this.featuresRepository.count(where);
    }
    async find(filter) {
        return this.featuresRepository.find(filter);
    }
    async updateAll(features, where) {
        return this.featuresRepository.updateAll(features, where);
    }
    async findById(id, filter) {
        return this.featuresRepository.findById(id, filter);
    }
    async updateById(id, features) {
        await this.featuresRepository.updateById(id, features);
    }
    async replaceById(id, features) {
        await this.featuresRepository.replaceById(id, features);
    }
    async deleteById(id) {
        await this.featuresRepository.deleteById(id);
    }
};
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.CreateFeature] }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Features model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.Features) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Features, {
                    title: 'NewFeatures',
                }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Features]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "create", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewFeature] }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Features model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.where(models_1.Features)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "count", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewFeature] }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of Features model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.Features, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.filter(models_1.Features)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "find", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateFeature] }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Features PATCH success count',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Features, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__param)(1, rest_1.param.where(models_1.Features)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Features, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "updateAll", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewFeature] }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Features model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Features, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, rest_1.param.filter(models_1.Features, { exclude: 'where' })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "findById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateFeature] }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Features PATCH success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Features, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Features]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "updateById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateFeature] }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Features PUT success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)()),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Features]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "replaceById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.DeleteFeature] }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Features DELETE success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], FeaturesController.prototype, "deleteById", null);
FeaturesController = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, repository_1.repository)(repositories_1.FeaturesRepository)),
    (0, tslib_1.__metadata)("design:paramtypes", [repositories_1.FeaturesRepository])
], FeaturesController);
exports.FeaturesController = FeaturesController;
//# sourceMappingURL=features.controller.js.map