"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectsController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const enums_1 = require("../enums");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/projects';
let ProjectsController = class ProjectsController {
    constructor(projectsRepository) {
        this.projectsRepository = projectsRepository;
    }
    async create(projects) {
        return this.projectsRepository.create(projects);
    }
    async count(where) {
        return this.projectsRepository.count(where);
    }
    async find(filter) {
        return this.projectsRepository.find(filter);
    }
    async updateAll(projects, where) {
        return this.projectsRepository.updateAll(projects, where);
    }
    async findById(id, filter) {
        return this.projectsRepository.findById(id, filter);
    }
    async updateById(id, projects) {
        await this.projectsRepository.updateById(id, projects);
    }
    async replaceById(id, projects) {
        await this.projectsRepository.replaceById(id, projects);
    }
    async deleteById(id) {
        await this.projectsRepository.deleteById(id);
    }
};
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.CreateProject] }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Projects model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.Projects) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Projects, {
                    title: 'NewProjects',
                }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Projects]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "create", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewProject] }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Projects model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.where(models_1.Projects)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "count", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewProject] }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of Projects model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            schema: {
                                type: 'array',
                                items: (0, rest_1.getModelSchemaRef)(models_1.Projects, { includeRelations: true }),
                            },
                        },
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.filter(models_1.Projects)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "find", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateProject] }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Projects PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Projects, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__param)(1, rest_1.param.where(models_1.Projects)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Projects, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "updateAll", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewProject] }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Projects model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Projects, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, rest_1.param.filter(models_1.Projects, { exclude: 'where' })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "findById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateProject] }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Projects PATCH success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Projects, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Projects]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "updateById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateProject] }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Projects PUT success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)()),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Projects]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "replaceById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.DeleteProject] }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Projects DELETE success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], ProjectsController.prototype, "deleteById", null);
ProjectsController = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, repository_1.repository)(repositories_1.ProjectsRepository)),
    (0, tslib_1.__metadata)("design:paramtypes", [repositories_1.ProjectsRepository])
], ProjectsController);
exports.ProjectsController = ProjectsController;
//# sourceMappingURL=projects.controller.js.map