"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StrategiesController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const enums_1 = require("../enums");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/strategies';
let StrategiesController = class StrategiesController {
    constructor(strategiesRepository) {
        this.strategiesRepository = strategiesRepository;
    }
    async create(strategies) {
        return this.strategiesRepository.create(strategies);
    }
    async count(where) {
        return this.strategiesRepository.count(where);
    }
    async find(filter) {
        return this.strategiesRepository.find(filter);
    }
    async updateAll(strategies, where) {
        return this.strategiesRepository.updateAll(strategies, where);
    }
    async findById(id, filter) {
        return this.strategiesRepository.findById(id, filter);
    }
    async updateById(id, strategies) {
        await this.strategiesRepository.updateById(id, strategies);
    }
    async replaceById(id, strategies) {
        await this.strategiesRepository.replaceById(id, strategies);
    }
    async deleteById(id) {
        await this.strategiesRepository.deleteById(id);
    }
};
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.CreateStrategy] }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategies model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.Strategies) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategies, {
                    title: 'NewStrategies',
                }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Strategies]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "create", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategies model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.where(models_1.Strategies)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "count", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of Strategies model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.Strategies, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.filter(models_1.Strategies)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "find", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategies PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategies, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__param)(1, rest_1.param.where(models_1.Strategies)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Strategies, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "updateAll", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategies model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Strategies, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, rest_1.param.filter(models_1.Strategies, { exclude: 'where' })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "findById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategies PATCH success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategies, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Strategies]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "updateById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategies PUT success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)()),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Strategies]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "replaceById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.DeleteStrategy] }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategies DELETE success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategiesController.prototype, "deleteById", null);
StrategiesController = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, repository_1.repository)(repositories_1.StrategiesRepository)),
    (0, tslib_1.__metadata)("design:paramtypes", [repositories_1.StrategiesRepository])
], StrategiesController);
exports.StrategiesController = StrategiesController;
//# sourceMappingURL=strategies.controller.js.map